﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using LiveCharts.Wpf;
using LiveCharts;

namespace GraficarEcuacion2
{
    internal class Graficador
    {
        // Atributos privados
        private List<Punto> _listaPuntos = new List<Punto>();
        private string _strEtiquetaX, _strEtiquetaY;
        

        // Constructor
        public Graficador(string strEtiquetaX, string strEtiquetaY)
        {
            this.EtiquetaX = strEtiquetaX;
            this.EtiquetaY = strEtiquetaY;
        }

        // Propiedades públicas
        public string EtiquetaX
        {
            set {  _strEtiquetaX = value;}
            get { return _strEtiquetaX; }
        }

        public string EtiquetaY
        {
            set { _strEtiquetaY = value; }
            get { return _strEtiquetaY; }
        }
        // Método para insertar un punto de la gráfica
        public void InsertarPunto(Punto nuevoPunto)
        {
            _listaPuntos.Add(nuevoPunto);
        }

        // Destructor
        ~Graficador()
        {
            _listaPuntos.Clear();
        }

        // Método para generar la gráfica en el control visual de tipo CartesianChart
        public void Graficar(LiveCharts.WinForms.CartesianChart miGrafica)
        {
            miGrafica.Series.Clear(); // Limpia la serie de puntos
            miGrafica.AxisX.Clear(); // Limpia las etiquetas del eje X
            miGrafica.AxisY.Clear();// Limpia las etiquetas del eje Y
            miGrafica.DisableAnimations=true; // Desactiva la animación de la gráfica

            // Arreglo que almacena las etiquetas de los puntos
            string [] arregloEtiquetas = new string [_listaPuntos.Count];
            for (int i = 0; i < _listaPuntos.Count; i++)
                arregloEtiquetas[i] = _listaPuntos[i].Etiqueta;

            // Coloca las etiquetas de los puntos en el eje X
            miGrafica.AxisX.Add(new LiveCharts.Wpf.Axis
            {
                Title = EtiquetaX,
                Labels = arregloEtiquetas
            });

            // Coloca las etiquetas de los puntos en el eje Y
            miGrafica.AxisY.Add(new LiveCharts.Wpf.Axis
            {
                Title = EtiquetaY,
            });

            miGrafica.LegendLocation = LiveCharts.LegendLocation.Right; // Ubicación de las etiquetas

            SeriesCollection serie = new SeriesCollection(); // Crea la serie

            // Crea una lista con los valores de los puntos
            List<double> listaValores = new List<double>();
            foreach (Punto unPunto in _listaPuntos)
                listaValores.Add(unPunto.Valor);

            // Genera la serie con la lista de valores de los puntos
            serie.Add(new LineSeries() { Title = this.EtiquetaY.ToString(), Values = new ChartValues<double>(listaValores), PointGeometrySize=5, StrokeThickness=1 });

            miGrafica.Series = serie;  // Genera la gráfica
        }

    }
}
